@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from PySide import QtGui, QtCore
+from calculate.consolegui import qt
 import time, urllib2
 from calculate.core.client.function import create_obj
 
@@ -27,17 +27,17 @@ import dbus
 from ReturnMessage import ReturnedMessage
 from calculate.consolegui.application.pid_information import client_pid_info, \
     client_list_pid
-from more import show_msg, get_sid, _print
+from more import show_msg, get_sid, _print, get_icon
 
-# class MySignal(QtCore.QObject):
-#    sig = QtCore.Signal(str, str)
+# class MySignal(qt.QObject):
+#    sig = qt.Signal(str, str)
 
-class TrayUpdateSystem(QtCore.QThread):
-    mes_sig = QtCore.Signal(str, str)
-    started_sig = QtCore.Signal(str)
+class TrayUpdateSystem(qt.QThread):
+    mes_sig = qt.Signal(str, str)
+    started_sig = qt.Signal(str)
 
     def __init__(self, target, parent=None):
-        QtCore.QThread.__init__(self, parent)
+        qt.QThread.__init__(self, parent)
         self._parent = target
 
     def run(self):
@@ -88,10 +88,10 @@ class TrayUpdateSystem(QtCore.QThread):
             self._parent.localhost_ClientObj.process_dict \
                 [meth_result[0].message]['name'] = method_name
             self._parent.localhost_ClientObj.process_dict \
-                [meth_result[0].message]['layout'] = QtGui.QVBoxLayout()
+                [meth_result[0].message]['layout'] = qt.QVBoxLayout()
             self._parent.localhost_ClientObj.process_dict \
                 [meth_result[0].message]['layout'].setAlignment \
-                (QtCore.Qt.AlignTop)
+                (qt.Qt.AlignTop)
         else:
             return 1
 
@@ -147,7 +147,7 @@ class TrayUpdateSystem(QtCore.QThread):
         self.close_flag = True
 
 
-class TrayIcon(QtGui.QSystemTrayIcon):
+class TrayIcon(qt.QSystemTrayIcon):
     default_theme_name = 'Tango'
 
     def __init__(self, parent):
@@ -155,7 +155,7 @@ class TrayIcon(QtGui.QSystemTrayIcon):
         self._parent = parent
         self.actions = []
 
-        self.setIcon(QtGui.QIcon(
+        self.setIcon(get_icon(
             '/usr/share/pixmaps/calculate-console-offline.svg'))
 
         self.is_online_icon = False
@@ -175,18 +175,6 @@ class TrayIcon(QtGui.QSystemTrayIcon):
         self.update_thread.mes_sig.connect(self.showMessage)
         self.update_thread.started_sig.connect(self.showUpdate)
 
-    def select_icon(self, icons):
-        old_theme_name = QtGui.QIcon.themeName()
-        try:
-            for theme_name in (old_theme_name, self.default_theme_name):
-                QtGui.QIcon.setThemeName(theme_name)
-                for image in icons:
-                    if QtGui.QIcon.hasThemeIcon(image):
-                        return QtGui.QIcon.fromTheme(image)
-            return QtGui.QIcon()
-        finally:
-            QtGui.QIcon.setThemeName(old_theme_name)
-
     def generation_actions(self):
         _("About")
         _("Report a Bug")
@@ -222,12 +210,12 @@ class TrayIcon(QtGui.QSystemTrayIcon):
         }
         for action_name, action_data in self.actions.items():
             setattr(self, '%s_action' % action_name,
-                    QtGui.QAction(self.select_icon(action_data['icons']),
-                                  _(action_data['label']), self,
-                                  triggered=action_data['trigger']))
+                    qt.QAction(get_icon(*action_data['icons']),
+                               _(action_data['label']), self,
+                               triggered=action_data['trigger']))
 
     def create_menu(self, *actions):
-        menu = QtGui.QMenu()
+        menu = qt.QMenu()
         for action in actions:
             if action:
                 menu.addAction(getattr(self, "%s_action" % action))
@@ -247,15 +235,9 @@ class TrayIcon(QtGui.QSystemTrayIcon):
         return False
 
     def set_icon(self, online, has_update=None):
-        if has_update is None:
-            if self.check_for_update():
-                has_update = True
-            else:
-                has_update = False
-
         if online:
             if not self.is_online_icon:
-                self.setIcon(QtGui.QIcon(
+                self.setIcon(get_icon(
                     '/usr/share/pixmaps/calculate-console-online.svg'))
                 # для решения странного размера иконки в mate
                 self.hide()
@@ -263,7 +245,7 @@ class TrayIcon(QtGui.QSystemTrayIcon):
                 self.is_online_icon = True
         else:
             if self.is_online_icon:
-                self.setIcon(QtGui.QIcon(
+                self.setIcon(get_icon(
                     '/usr/share/pixmaps/calculate-console-offline.svg'))
                 # для решения странного размера иконки в mate
                 self.hide()
@@ -330,18 +312,18 @@ class TrayIcon(QtGui.QSystemTrayIcon):
         #    informative_text = _('Stop updating and exit?')
         #    reply = show_question(self._parent, text, informative_text)
 
-        #    if reply == QtGui.QMessageBox.No:
+        #    if reply == qt.QMessageBox.No:
         #        return 0
 
-        #    elif reply == QtGui.QMessageBox.Yes:
+        #    elif reply == qt.QMessageBox.Yes:
         #        self.update_thread.close()
         #        self.update_thread.wait()
         self._parent._closeEvent()
 
     def activ(self, reason):
-        if reason == QtGui.QSystemTrayIcon.Trigger:
+        if reason == qt.QSystemTrayIcon.Trigger:
             self.windowVisible()
-        if reason == QtGui.QSystemTrayIcon.DoubleClick:
+        if reason == qt.QSystemTrayIcon.DoubleClick:
             self.windowVisible()
 
     def showMessage(self, title, message, icon='dialog-warning'):
